==> atlassian-util-concurrent-2.0.0-sources.jar: com/atlassian/util/concurrent/RuntimeTimeoutException.java <==
/**
 * Copyright 2010 Atlassian Pty Ltd 
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

package com.atlassian.util.concurrent;

import static com.atlassian.util.concurrent.Assertions.notNull;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

/**
 * Convenience class for re-throwing {@link TimeoutException} as an unchecked
 * exception.
 */
public class RuntimeTimeoutException extends RuntimeException {

    private static final long serialVersionUID = -5025209597479375477L;

    public RuntimeTimeoutException(final TimeoutException cause) {
        super(notNull("cause", cause));
    }

    public RuntimeTimeoutException(final String message, final TimeoutException cause) {
        super(message, notNull("cause", cause));
    }

    public RuntimeTimeoutException(final long time, final TimeUnit unit) {
        super(new TimedOutException(time, unit));
    }

    @Override
    public TimeoutException getCause() {
        return (TimeoutException) super.getCause();
    }
}

==> atlassian-util-concurrent-2.4.0-sources.jar: com/atlassian/util/concurrent/RuntimeTimeoutException.java <==
/**
 * Copyright 2010 Atlassian Pty Ltd 
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

package com.atlassian.util.concurrent;

import static com.atlassian.util.concurrent.Assertions.notNull;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

/**
 * Convenience class for re-throwing {@link TimeoutException} as an unchecked
 * exception.
 */
public class RuntimeTimeoutException extends RuntimeException {

  private static final long serialVersionUID = -5025209597479375477L;

  public RuntimeTimeoutException(final TimeoutException cause) {
    super(notNull("cause", cause));
  }

  public RuntimeTimeoutException(final String message, final TimeoutException cause) {
    super(message, notNull("cause", cause));
  }

  public RuntimeTimeoutException(final long time, final TimeUnit unit) {
    super(new TimedOutException(time, unit));
  }

  @Override public TimeoutException getCause() {
    return (TimeoutException) super.getCause();
  }
}
